#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
from pathlib import Path

try:
    from crypto_utils import get_author_info
    _info = get_author_info()
    APP_NAME = _info.get('app_name', '[Protected]')
    APP_VERSION = _info.get('version_number', '[Protected]')
    APP_AUTHOR = _info.get('author_name', '[Protected]')
    APP_YEAR = "2025"
except:
    APP_NAME = "[Protected]"
    APP_VERSION = "[Protected]"
    APP_AUTHOR = "[Protected]"
    APP_YEAR = "2025"

DEFAULT_DOWNLOAD_PATH = os.path.join(os.path.expanduser("~"), "Downloads", "YouTube")
DEFAULT_QUALITY = "best"
DEFAULT_FORMAT = "mp4"

QUALITY_OPTIONS = [
    "best",
    "worst",
    "720p",
    "480p",
    "360p",
    "240p",
    "144p"
]

FORMAT_OPTIONS = [
    "mp4",
    "webm",
    "mkv",
    "mp3",
    "m4a",
    "wav"
]

AUDIO_FORMATS = ["mp3", "m4a", "wav", "aac", "ogg", "flac"]

YOUTUBE_URL_PATTERNS = [
    r'(?:https?://)?(?:www\.)?youtube\.com/watch\?v=[\w-]+',
    r'(?:https?://)?(?:www\.)?youtu\.be/[\w-]+',
    r'(?:https?://)?(?:www\.)?youtube\.com/embed/[\w-]+',
    r'(?:https?://)?(?:www\.)?youtube\.com/v/[\w-]+'
]

DOWNLOAD_TIMEOUT = 300
MAX_RETRIES = 3
CHUNK_SIZE = 8192

YTDLP_DOWNLOAD_URL = "https://github.com/yt-dlp/yt-dlp/releases/latest/download/yt-dlp.exe"
FFMPEG_DOWNLOAD_URL = "https://www.gyan.dev/ffmpeg/builds/ffmpeg-release-essentials.zip"

BIN_DIR = os.path.join(os.path.dirname(__file__), "bin")
YTDLP_PATH = os.path.join(BIN_DIR, "yt-dlp.exe")
FFMPEG_PATH = os.path.join(BIN_DIR, "ffmpeg.exe")

LOG_FORMAT = "[%(asctime)s] %(levelname)s: %(message)s"
LOG_DATE_FORMAT = "%Y-%m-%d %H:%M:%S"

try:
    _version_short = _info.get('version_short', '[Protected]')
    WINDOW_TITLE = f"{APP_NAME} - {_version_short} V{APP_VERSION}"
except:
    WINDOW_TITLE = "[Protected]"
WINDOW_SIZE = "800x600"
WINDOW_MIN_SIZE = (600, 400)

COLORS = {
    "primary": "#2196F3",
    "success": "#4CAF50",
    "warning": "#FF9800",
    "error": "#F44336",
    "info": "#2196F3",
    "light": "#F5F5F5",
    "dark": "#212121"
}

FONTS = {
    "default": ("Microsoft YaHei UI", 9),
    "title": ("Microsoft YaHei UI", 12, "bold"),
    "button": ("Microsoft YaHei UI", 9),
    "log": ("Consolas", 8)
}

ERROR_MESSAGES = {
    "no_url": "请输入YouTube视频链接",
    "invalid_url": "请输入有效的YouTube视频链接",
    "download_failed": "下载失败，请检查网络连接和视频链接",
    "ytdlp_not_found": "yt-dlp未找到，请重新启动程序",
    "network_error": "网络连接错误，请检查网络设置",
    "permission_error": "权限错误，请检查下载路径的写入权限",
    "disk_space_error": "磁盘空间不足，请清理磁盘空间",
    "format_error": "格式错误，请尝试更换输出格式"
}

SUCCESS_MESSAGES = {
    "download_complete": "视频下载完成！",
    "info_retrieved": "视频信息获取成功",
    "dependencies_ready": "依赖项检查完成"
}

STATUS_MESSAGES = {
    "ready": "就绪",
    "downloading": "下载中...",
    "processing": "处理中...",
    "getting_info": "获取视频信息中...",
    "checking_deps": "检查依赖项...",
    "download_complete": "下载完成",
    "download_failed": "下载失败",
    "cancelled": "已取消"
}

def get_config_dir():
    if os.name == 'nt':
        config_dir = os.path.join(os.environ.get('APPDATA', ''), APP_NAME)
    else:
        config_dir = os.path.join(os.path.expanduser('~'), f'.{APP_NAME.lower()}')
    
    os.makedirs(config_dir, exist_ok=True)
    return config_dir

def get_temp_dir():
    import tempfile
    temp_dir = os.path.join(tempfile.gettempdir(), APP_NAME)
    os.makedirs(temp_dir, exist_ok=True)
    return temp_dir

os.makedirs(BIN_DIR, exist_ok=True)
os.makedirs(DEFAULT_DOWNLOAD_PATH, exist_ok=True) 