#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import base64
import hashlib
from cryptography.fernet import Fernet
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
import os

class CryptoManager:
    def __init__(self, password=None):
        if password is None:
            password = self._get_default_key()
        self.key = self._derive_key(password)
        self.cipher = Fernet(self.key)
    
    def _get_default_key(self):
        return "YT_DOWNLOADER_2025_NIRENCHUANSHUO_PROTECTED"
    
    def _derive_key(self, password):
        from cryptography.hazmat.backends import default_backend
        password = password.encode()
        salt = b'salt_for_yt_downloader_2025'
        kdf = PBKDF2HMAC(
            algorithm=hashes.SHA256(),
            length=32,
            salt=salt,
            iterations=100000,
            backend=default_backend()
        )
        key = base64.urlsafe_b64encode(kdf.derive(password))
        return key
    
    def encrypt(self, data):
        if isinstance(data, str):
            data = data.encode()
        encrypted = self.cipher.encrypt(data)
        return base64.urlsafe_b64encode(encrypted).decode()
    
    def decrypt(self, encrypted_data):
        try:
            encrypted_data = base64.urlsafe_b64decode(encrypted_data.encode())
            decrypted = self.cipher.decrypt(encrypted_data)
            return decrypted.decode()
        except:
            return None

_crypto_manager = CryptoManager()

def encrypt_string(data):
    return _crypto_manager.encrypt(data)

def decrypt_string(encrypted_data):
    return _crypto_manager.decrypt(encrypted_data)

ENCRYPTED_AUTHOR_INFO = {
    'author_name': 'Z0FBQUFBQm9TOHBMOURuLS05X3psV0Qwekt4S3ZNZUtuTkw3LXNaQXQ2UkJMeDdFWHMtN2hQT2R1QWRZUUQ2OVZ4RnhBQ0o3ZGNNTU9JWGhHTTNCMWJlbkFXd3g1NDZVa1E9PQ==',
    'author_website': 'Z0FBQUFBQm9TOHBMV1huaHVNaUpHX3ZuZUR3b2Y3Y3NWbUJZU0xmMzFCeWZYV2swY0czR1d3N21KclppMTZhc3EtTTdHU0xmWnFybFZQUXN0eWxway1CTjZmZnVZaXB5UE9zR3pQVkVPR1k0QUJKYkRfanpBMmc9',
    'version': 'Z0FBQUFBQm9TOHBMdnZYM0M1b2EwYkFsMGRXdXlBZHgwSkVCbF9UOFAxY25XUlQ4QXEyRlFyZkNFYXBDMWV2QmhGc1pRekpaZ1NRVXpmNnJuMk9YZ0NTSElqajZ5VmZ6b05FOF9jQVZOU045TVpOT284bzk5eTQ9',
    'app_title': 'Z0FBQUFBQm9TOHBMaHBkMDE2WGk0dGpOMjFzWWwtaU9iLU0yLTk5QlRTNWJHTmJkaWdKZ1J1T1J2RmpYNGx5YnJMZlRQcUFKZDNZbV9pcFRkcHQ=',
    'main_title': 'Z0FBQUFBQm9TOUJxc3Y5RDlvVVhUWlY1Y3d2OE5fUFdnNlVsU01HWC1DN21XVW54bVlLOXJtSFVFUUdxZWpCSGxHVUE4b0RKa3lLRTRQNGJYbEZjSkdJcDRGUVRjdElGb0hDeTk5dkc0bzBUWFZlUktDRmhTSGNWaWdrYmEyT0FnZHZjbWZ4Mnctckc=',
    'app_name': 'Z0FBQUFBQm9TOVJLaVJWQVlqaHFfZWw0UXlianU3cDVWUTQtLXhxYU5FMkpQUHMxUHo0VmhsTkIyZUJrbjJDTFdiZWtoQXhZT3dLdnVsbmtLaHZ6Nm5XZkh3RlI3YVV1QTR5c3RFYWl2VU9IVGdzOWhXdFFLZ1k9',
    'version_short': 'Z0FBQUFBQm9TOVJLdnY1dFhNSThWNXRaRTNOUVhZSDVDLXdkUndyR2hMeGktdDJQN3JsZjJXX1JEQ3pnWEdlY3Y1YmoyTUpHRjBOVGNTQ2N4TVI1TlJabDZrbVNYTjlPOEE9PQ==',
    'version_number': 'Z0FBQUFBQm9TOVJLYllwdnhrdjdpT0J0XzEtUnM3QXdTaF9YTm1DQWxfTjkzeGIzaFdOa21nT2lWUmJYcnVqNUpiV2ViU1otODdiWEFJX0o3M0pxMXVPc0ZPenNURWlhX3c9PQ==',
    'title_with_icon': 'Z0FBQUFBQm9TOVJLcE1mdU8zSS1lYUl1Zk94eHplZldzOHE2d1dGaUJwZ2N2MVNtUjZXR3hYZlZSNFlVdFpWZ1RjM21Ec2dJaF9xYmVVRVRBbmhFVy0wSU5Jamx3bWprR2dqYzhxeVhrdW02WmJVR0I4R1FRX1U9',
    'basic_suffix': 'Z0FBQUFBQm9TOVJLQU5oNHFrWU1HdHZsdlJKbUNXUlRfQlgweTV6a3JNMFVfRE1TQ0x0YXJvOEtpNXNjUEhlYkl3cjRzSkFVOGNqMmt2OWNMREJPVUh3MXl3c2FNU3dSWHc9PQ=='
}

def get_author_info():
    try:
        return {
            'author_name': decrypt_string(ENCRYPTED_AUTHOR_INFO['author_name']),
            'author_website': decrypt_string(ENCRYPTED_AUTHOR_INFO['author_website']),
            'version': decrypt_string(ENCRYPTED_AUTHOR_INFO['version']),
            'app_title': decrypt_string(ENCRYPTED_AUTHOR_INFO['app_title']),
            'main_title': decrypt_string(ENCRYPTED_AUTHOR_INFO['main_title']),
            'app_name': decrypt_string(ENCRYPTED_AUTHOR_INFO['app_name']),
            'version_short': decrypt_string(ENCRYPTED_AUTHOR_INFO['version_short']),
            'version_number': decrypt_string(ENCRYPTED_AUTHOR_INFO['version_number']),
            'title_with_icon': decrypt_string(ENCRYPTED_AUTHOR_INFO['title_with_icon']),
            'basic_suffix': decrypt_string(ENCRYPTED_AUTHOR_INFO['basic_suffix'])
        }
    except Exception as e:
        return {
            'author_name': '[Protected]',
            'author_website': '[Protected]',
            'version': '[Protected]',
            'app_title': '[Protected]',
            'main_title': '[Protected]',
            'app_name': '[Protected]',
            'version_short': '[Protected]',
            'version_number': '[Protected]',
            'title_with_icon': '[Protected]',
            'basic_suffix': '[Protected]'
        } 